@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2022 Teclib' and contributors.
+ * @copyright 2015-2023 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -54,13 +54,26 @@ if (
     && $_SESSION["glpiauthtype"] == Auth::CAS
     && Toolbox::canUseCAS()
 ) {
-    phpCAS::client(
-        CAS_VERSION_2_0,
-        $CFG_GLPI["cas_host"],
-        intval($CFG_GLPI["cas_port"]),
-        $CFG_GLPI["cas_uri"],
-        false
-    );
+    if (version_compare(phpCAS::getVersion(), '1.6.0', '<')) {
+        // Prior to version 1.6.0, 5th argument was `$changeSessionID`.
+        phpCAS::client(
+            constant($CFG_GLPI["cas_version"]),
+            $CFG_GLPI["cas_host"],
+            intval($CFG_GLPI["cas_port"]),
+            $CFG_GLPI["cas_uri"],
+            false
+        );
+    } else {
+        // Starting from version 1.6.0, 5th argument is `$service_base_url`.
+        phpCAS::client(
+            constant($CFG_GLPI["cas_version"]),
+            $CFG_GLPI["cas_host"],
+            intval($CFG_GLPI["cas_port"]),
+            $CFG_GLPI["cas_uri"],
+            $CFG_GLPI["url_base"],
+            false
+        );
+    }
     phpCAS::setServerLogoutURL(strval($CFG_GLPI["cas_logout"]));
     phpCAS::logout();
 }
