@@ -34,6 +34,7 @@
  */
 
 use Glpi\Event;
+use Glpi\Toolbox\Sanitizer;
 
 include('../inc/includes.php');
 
@@ -47,6 +48,15 @@ if (!isset($_GET["withtemplate"])) {
     $_GET["withtemplate"] = "";
 }
 
+if (array_key_exists('auth_passphrase', $_POST)) {
+    // Passphrase must not be altered, it will be encrypted and never displayed, so sanitize is not necessary.
+    $_POST['auth_passphrase'] = Sanitizer::unsanitize($_POST['auth_passphrase']);
+}
+if (array_key_exists('priv_passphrase', $_POST)) {
+    // Passphrase must not be altered, it will be encrypted and never displayed, so sanitize is not necessary.
+    $_POST['priv_passphrase'] = Sanitizer::unsanitize($_POST['priv_passphrase']);
+}
+
 $cred = new SNMPCredential();
 if (isset($_POST["add"])) {
     $cred->check(-1, CREATE, $_POST);
