@@ -34,15 +34,26 @@
  */
 
 /**
+ * @var DB $DB
  * @var Migration $migration
  */
 
+use Glpi\Agent\Communication\AbstractRequest;
+
 $migration->displayMessage('Add new configurations / user preferences');
+$migration->addPreQuery(
+    $DB->buildUpdate(
+        Config::getTable(),
+        [
+            'context' => 'inventory'
+        ],
+        [
+            'name' => 'inventory_frequency',
+            'context' => 'core'
+        ]
+    )
+);
 $migration->addConfig(
-    [
-        'import_monitor' => 1,
-        'import_printer' => 1,
-        'import_peripheral' => 1
-    ],
+    ['inventory_frequency' => AbstractRequest::DEFAULT_FREQUENCY],
     'inventory'
 );
