@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2022 Teclib' and contributors.
+ * @copyright 2015-2023 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -38,6 +38,8 @@
  * @var Migration $migration
  */
 
-// This key may be missing from database on GLPI instances that were migrated to 10.0 version
-// prior to #9703 (so prior to 10.0.0-beta).
-$migration->addKey('glpi_refusedequipments', 'autoupdatesystems_id');
+
+// Remove '' default values on glpi_impactcontexts.positions
+// MySQL does not allow default values on TEXT fields, while MariaDB does
+// Default was removed in installation file GLPI 9.5.4, see #8415
+$migration->changeField('glpi_impactcontexts', 'positions', 'positions', 'mediumtext NOT NULL');
