@@ -42,9 +42,12 @@ require('codemirror/addon/fold/comment-fold.js');
 require('codemirror/addon/fold/foldgutter.js');
 require('codemirror/addon/hint/show-hint.js');
 require('codemirror/addon/hint/css-hint.js');
+require('codemirror/addon/runmode/runmode.js');
 
 require('codemirror/addon/fold/foldgutter.css');
 require('codemirror/addon/hint/show-hint.css');
 
 // Codemirror language modes
 require('codemirror/mode/css/css.js');
+require('codemirror/mode/sql/sql.js');
+require('codemirror/mode/javascript/javascript.js');
