@@ -104,7 +104,7 @@ class APIRest extends API
         $is_inline_doc = (strlen($resource) == 0) || ($resource == "api");
 
         // Add headers for CORS
-        $this->cors($this->verb);
+        $this->cors();
 
         // retrieve paramaters (in body, query_string, headers)
         $this->parseIncomingParams($is_inline_doc);
@@ -159,22 +159,22 @@ class APIRest extends API
             $this->returnResponse($this->getMyEntities($this->parameters));
         } elseif ($resource === "getActiveEntities") {
             // get curent active entity
-            $this->returnResponse($this->getActiveEntities($this->parameters));
+            $this->returnResponse($this->getActiveEntities());
         } elseif ($resource === "changeActiveProfile") {
             // change active profile
             $this->returnResponse($this->changeActiveProfile($this->parameters));
         } elseif ($resource === "getMyProfiles") {
             // get all profiles of current logged user
-            $this->returnResponse($this->getMyProfiles($this->parameters));
+            $this->returnResponse($this->getMyProfiles());
         } elseif ($resource === "getActiveProfile") {
             // get current active profile
-            $this->returnResponse($this->getActiveProfile($this->parameters));
+            $this->returnResponse($this->getActiveProfile());
         } elseif ($resource === "getFullSession") {
             // get complete php session
-            $this->returnResponse($this->getFullSession($this->parameters));
+            $this->returnResponse($this->getFullSession());
         } elseif ($resource === "getGlpiConfig") {
             // get complete php var $CFG_GLPI
-            $this->returnResponse($this->getGlpiConfig($this->parameters));
+            $this->returnResponse($this->getGlpiConfig());
         } elseif ($resource === "listSearchOptions") {
             // list searchOptions of an itemtype
             $itemtype = $this->getItemtype(1);
