@@ -975,16 +975,16 @@ abstract class CommonDropdown extends CommonDBTM
                     $ret .= "</div>"; // .faqadd_block_content
                 } else {
                     $ret .= Html::scriptBlock("
-                  var getKnowbaseItemAnswer$rand = function() {
-                     var knowbaseitems_id = $('#dropdown_knowbaseitems_id$rand').val();
-                     $('#faqadd_block_content$rand').load(
-                        '" . $CFG_GLPI['root_doc'] . "/ajax/getKnowbaseItemAnswer.php',
-                        {
-                           'knowbaseitems_id': knowbaseitems_id
-                        }
-                     );
-                  };
-               ");
+                        var getKnowbaseItemAnswer$rand = function() {
+                            var knowbaseitems_id = $('#dropdown_knowbaseitems_id$rand').val();
+                            $('#faqadd_block_content$rand').load(
+                                '" . $CFG_GLPI['root_doc'] . "/ajax/getKnowbaseItemAnswer.php',
+                                {
+                                    'knowbaseitems_id': knowbaseitems_id
+                                }
+                            );
+                        };
+                    ");
                     $ret .= "<label for='dropdown_knowbaseitems_id$rand'>" .
                     KnowbaseItem::getTypeName() . "</label>&nbsp;";
                     $ret .= KnowbaseItem::dropdown([
@@ -998,6 +998,14 @@ abstract class CommonDropdown extends CommonDBTM
                     $ret .= $kbitem->showFull(['display' => false]);
                     $ret .= "</div>"; // .faqadd_block_content
                 }
+                $ret .= Html::scriptBlock("
+                        var setMaxWidth = function() {
+                            var maxWidth = $('#faqadd_block_content$rand').closest('.form-field').width();
+                            $('.faqadd_entries').css('max-width', maxWidth);
+                        }
+                        $(window).resize(setMaxWidth);
+                        setMaxWidth();
+                    ");
                 $ret .= "</div>"; // .faqadd_entries
                 $ret .= "</div>"; // .faqadd_block
             }
