@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2022 Teclib' and contributors.
+ * @copyright 2015-2023 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -140,7 +140,7 @@ class AppliancesPluginToCoreCommand extends AbstractCommand
     {
         parent::configure();
 
-        $this->setName('glpi:migration:appliances_plugin_to_core');
+        $this->setName('migration:appliances_plugin_to_core');
         $this->setDescription(__('Migrate Appliances plugin data into GLPI core tables'));
 
         $this->addOption(
