@@ -393,6 +393,21 @@ class Contract extends CommonDBTM
             'datatype'           => 'specific'
         ];
 
+        $tab[] = [
+            'id'                 => '139',
+            'table'              => 'glpi_locations',
+            'field'              => 'completename',
+            'name'               => Location::getTypeName(1),
+            'datatype'           => 'dropdown',
+            'massiveaction'      => false,
+            'joinparams'         => [
+                'beforejoin'         => [
+                    'table'              => 'glpi_contracts',
+                    'joinparams'         => $joinparams
+                ]
+            ]
+        ];
+
         return $tab;
     }
 
@@ -570,6 +585,14 @@ class Contract extends CommonDBTM
             'unit'               => 'month'
         ];
 
+        $tab[] = [
+            'id'                 => '8',
+            'table'              => 'glpi_locations',
+            'field'              => 'completename',
+            'name'               => Location::getTypeName(1),
+            'datatype'           => 'dropdown'
+        ];
+
         $tab[] = [
             'id'                 => '21',
             'table'              => $this->getTable(),
@@ -1782,6 +1805,9 @@ class Contract extends CommonDBTM
         return "ti ti-writing-sign";
     }
 
+    /**
+     * @FIXME Rename method in GLPI 10.1. Method returns criteria to find NOT expired contracts.
+     */
     public static function getExpiredCriteria()
     {
         global $DB;
