@@ -35,6 +35,7 @@
 
 namespace Glpi\Dashboard;
 
+use Glpi\Toolbox\Sanitizer;
 use Ramsey\Uuid\Uuid;
 use Session;
 
@@ -143,18 +144,59 @@ class Dashboard extends \CommonDBTM
      */
     public function canViewCurrent(): bool
     {
-       // check global (admin) right
+        $this->load();
+
+        if ($this->fields['users_id'] === Session::getLoginUserID()) {
+            // User is always allowed to view its own dashboards.
+            return true;
+        }
+
+        // check global (admin) right
         if (self::canView() && !$this->isPrivate()) {
             return true;
         }
 
+        // check access rights defined using sharing feature
         $this->load();
 
-       //check shared rights
         $rights = self::convertRights($this->rights ?? []);
         return self::checkRights($rights);
     }
 
+    /**
+     * Check if user has right to update the current dashboard.
+     *
+     * @return bool
+     */
+    public function canUpdateCurrent(): bool
+    {
+        $this->load();
+
+        if ($this->fields['users_id'] === Session::getLoginUserID()) {
+            // User is always allowed to update its own dashboards.
+            return true;
+        }
+
+        return self::canUpdate();
+    }
+
+    /**
+     * Check if user has right to detele the current dashboard.
+     *
+     * @return bool
+     */
+    public function canDeleteCurrent(): bool
+    {
+        $this->load();
+
+        if ($this->fields['users_id'] === Session::getLoginUserID()) {
+            // User is always allowed to delete its own dashboards.
+            return true;
+        }
+
+        return self::canDelete();
+    }
+
 
     /**
      * Save the current dashboard instance to DB
@@ -174,6 +216,7 @@ class Dashboard extends \CommonDBTM
     ): string {
         $this->fields['name']   = $title;
         $this->fields['context'] = $context;
+        $this->fields['users_id'] = Session::getLoginUserID();
         $this->key    = \Toolbox::slugify($title);
         $this->items  = $items;
         $this->rights = $rights;
@@ -195,13 +238,18 @@ class Dashboard extends \CommonDBTM
     {
         global $DB, $GLPI_CACHE;
 
-        $DB->updateOrInsert(self::getTable(), [
-            'key'     => $this->key,
-            'name'    => $this->fields['name'],
-            'context' => $this->fields['context']
-        ], [
-            'key'  => $this->key
-        ]);
+        $DB->updateOrInsert(
+            self::getTable(),
+            Sanitizer::dbEscapeRecursive([
+                'key'      => $this->key,
+                'name'     => $this->fields['name'],
+                'context'  => $this->fields['context'],
+                'users_id' => $this->fields['users_id'],
+            ]),
+            [
+                'key'  => $this->key
+            ]
+        );
 
        // reload dashboard
         $this->getFromDB($this->key);
@@ -215,10 +263,6 @@ class Dashboard extends \CommonDBTM
         if (!$skip_child && count($this->rights) > 0) {
             $this->saveRights($this->rights);
         }
-
-       // invalidate dashboard cache
-        $cache_key = "dashboard_card_" . $this->key;
-        $GLPI_CACHE->delete($cache_key);
     }
 
 
@@ -339,6 +383,7 @@ class Dashboard extends \CommonDBTM
         $this->load();
 
         $this->fields['name'] = sprintf(__('Copy of %s'), $this->fields['name']);
+        $this->fields['users_id'] = Session::getLoginUserID();
         $this->key = \Toolbox::slugify($this->fields['name']);
 
        // replace gridstack_id (with uuid V4) in the copy, to avoid cache issue
