@@ -36,13 +36,13 @@
 namespace Glpi\Dashboard;
 
 use DateInterval;
-use DBConnection;
 use Dropdown;
 use Glpi\Application\View\TemplateRenderer;
 use Glpi\Plugin\Hooks;
 use Html;
 use Plugin;
 use Ramsey\Uuid\Uuid;
+use Reminder;
 use Session;
 use ShareDashboardDropdown;
 use Telemetry;
@@ -150,14 +150,6 @@ class Grid
                <i class="fas fa-spinner fa-spin fa-3x"></i>
             </div>
 HTML;
-           // manage cache
-            $dashboard_key = $this->current;
-            $footprint = sha1(serialize($card_options) .
-            ($_SESSION['glpiactiveentities_string'] ?? "") .
-            ($_SESSION['glpilanguage']));
-            $cache_key    = "dashboard_card_{$dashboard_key}_{$footprint}";
-            $card_options['cache_key'] = $cache_key;
-
             $this->addGridItem(
                 $card_html,
                 $gridstack_id,
@@ -195,7 +187,6 @@ HTML;
      */
     public static function canViewOneDashboard($context = null): bool
     {
-       // check global (admin) right
         if (Dashboard::canView()) {
             return true;
         }
@@ -240,7 +231,7 @@ HTML;
      *
      * @return void display html of the grid
      */
-    public function show(bool $mini = false)
+    public function show(bool $mini = false, ?string $token = null)
     {
         global $GLPI_CACHE;
 
@@ -258,7 +249,6 @@ HTML;
             $this->cell_margin = 3;
         }
 
-        $embed_str     = self::$embed ? "true" : "false";
         $embed_class   = self::$embed ? "embed" : "";
         $mini_class    = $mini ? "mini" : "";
 
@@ -285,11 +275,9 @@ HTML;
 
         // prepare all available cards
         $cards = $this->getAllDasboardCards();
-        $cards_json = json_encode($cards);
 
        // prepare all available widgets
         $all_widgets = Widget::getAllTypes();
-        $all_widgets_json = json_encode($all_widgets);
 
        // prepare labels
         $embed_label      = __("Share or embed this dashboard");
@@ -421,21 +409,25 @@ HTML;
         $ajax_cards = GLPI_AJAX_DASHBOARD;
         $cache_key  = sha1($_SESSION['glpiactiveentities_string '] ?? "");
 
+        $js_params = json_encode([
+            'current'       => $this->current,
+            'cols'          => $this->grid_cols,
+            'rows'          => $this->grid_rows,
+            'cell_margin'   => $this->cell_margin,
+            'rand'          => $rand,
+            'ajax_cards'    => $ajax_cards,
+            'all_cards'     => $cards,
+            'all_widgets'   => $all_widgets,
+            'context'       => $this->context,
+            'cache_key'     => $cache_key,
+            'embed'         => self::$embed,
+            'token'         => $token,
+            'entities_id'   => $_SESSION['glpiactive_entity'],
+            'is_recursive'  => $_SESSION['glpiactive_entity_recursive'] ? 1 : 0
+        ]);
         $js = <<<JAVASCRIPT
       $(function () {
-         new GLPIDashboard({
-            current:     '{$this->current}',
-            cols:        {$this->grid_cols},
-            rows:        {$this->grid_rows},
-            cell_margin: {$this->cell_margin},
-            rand:        '{$rand}',
-            embed:       {$embed_str},
-            ajax_cards:  {$ajax_cards},
-            all_cards:   {$cards_json},
-            all_widgets: {$all_widgets_json},
-            context:     "{$this->context}",
-            cache_key:   "{$cache_key}",
-         })
+         new GLPIDashboard({$js_params})
       });
 JAVASCRIPT;
         $js = Html::scriptBlock($js);
@@ -495,7 +487,7 @@ JAVASCRIPT;
         $_SESSION['glpiactiveentities_string'] = "'" . implode("', '", $entities) . "'";
 
        // show embeded dashboard
-        $this->show(true);
+        $this->show(true, $params['token']);
     }
 
     public static function getToken(string $dasboard = "", int $entities_id = 0, int $is_recursive = 0): string
@@ -536,8 +528,6 @@ JAVASCRIPT;
 
         if ($token !== $params['token']) {
             return false;
-            Html::displayRightError();
-            exit;
         }
 
         return true;
@@ -761,7 +751,8 @@ HTML;
         $params = array_merge($default_params, $params);
 
         $used         = array_flip($params['used']);
-        $list_filters = array_diff_key(Filter::getAll(), $used);
+        $filters      = Filter::getFilterChoices();
+        $list_filters = array_diff_key($filters, $used);
 
         $rand = mt_rand();
         echo "<form class='display-filter-form'>";
@@ -915,20 +906,9 @@ HTML;
             }
             $card = $cards[$card_id];
 
-            // allows plugins to control uniqueness of its cards in cache system
-            if (isset($card['custom_hash'])) {
-                $card_options['custom_hash'] = $card['custom_hash'];
-            }
-
-            // manage cache
-            $options_footprint = sha1(serialize($card_options) .
-                ($_SESSION['glpiactiveentities_string'] ?? "") .
-                ($_SESSION['glpilanguage']));
-
             $use_cache = !$force
                 && $_SESSION['glpi_use_mode'] != Session::DEBUG_MODE
                 && (!isset($card['cache']) || $card['cache'] == true);
-            $cache_key = "dashboard_card_{$dashboard}_{$options_footprint}";
             $cache_age = 40;
 
             if ($use_cache) {
@@ -937,12 +917,6 @@ HTML;
                 header('Cache-Control: public');
                 header('Cache-Control: max-age=' . $cache_age);
                 header('Expires: ' . gmdate('D, d M Y H:i:s \G\M\T', time() + $cache_age));
-
-                // server cache
-                $dashboard_cards = $GLPI_CACHE->get($cache_key, []);
-                if (isset($dashboard_cards[$gridstack_id])) {
-                    return (string)$dashboard_cards[$gridstack_id];
-                }
             }
 
             $html = "";
@@ -997,14 +971,7 @@ HTML;
             }
 
             $execution_time = round(microtime(true) - $start, 3);
-
-            // store server cache
-            if (strlen($dashboard)) {
-                $dashboard_cards = $GLPI_CACHE->get($cache_key, []);
-                $dashboard_cards[$gridstack_id] = $html;
-                $GLPI_CACHE->set($cache_key, $dashboard_cards, new \DateInterval("PT" . $cache_age . "S"));
-            }
-        } catch (\Exception $e) {
+        } catch (\Throwable $e) {
             $html = $render_error_html;
             $execution_time = round(microtime(true) - $start, 3);
             // Log the error message without exiting
@@ -1053,8 +1020,10 @@ HTML;
      */
     public function getFilterHtml(string $filter_id = "", $filter_values = ""): string
     {
-        if (method_exists("Glpi\Dashboard\Filter", $filter_id)) {
-            return call_user_func("Glpi\Dashboard\Filter::$filter_id", $filter_values);
+        foreach (Filter::getRegisteredFilterClasses() as $filter) {
+            if ($filter::getId() == $filter_id) {
+                return $filter::getHtml($filter_values);
+            }
         }
 
         return "";
@@ -1108,20 +1077,11 @@ HTML;
      */
     public static function getAllDashboardCardsCacheKey(): string
     {
-        $language = Session::getLanguage();
-
-        if (!$language) {
-            // Keep a log trace in case of unexpected session value
-            // This may help with debugging in the future
-            trigger_error(
-                "Unable to get current language, will default to 'getAllDashboardCards' key",
-                E_USER_WARNING
-            );
-
-            return "getAllDashboardCards";
-        }
-
-        return "getAllDashboardCards_$language";
+        return sprintf(
+            'getAllDashboardCards_%s_%s',
+            sha1(json_encode(Filter::getRegisteredFilterClasses())),
+            Session::getLanguage() ?? ''
+        );
     }
 
     /**
@@ -1138,40 +1098,8 @@ HTML;
         $cards = $GLPI_CACHE->get(self::getAllDashboardCardsCacheKey());
 
         if ($cards === null || $force) {
-            // anonymous fct for adding relevant filters to cards
-            $add_filters_fct = static function ($itemtable, $DB) {
-                $add_filters = [];
-                if ($DB->fieldExists($itemtable, "ititlcategories_id")) {
-                    $add_filters[] = "itilcategory";
-                }
-                if ($DB->fieldExists($itemtable, "requesttypes_id")) {
-                    $add_filters[] = "requesttype";
-                }
-                if ($DB->fieldExists($itemtable, "locations_id")) {
-                    $add_filters[] = "location";
-                }
-                if ($DB->fieldExists($itemtable, "manufacturers_id")) {
-                    $add_filters[] = "manufacturer";
-                }
-                if ($DB->fieldExists($itemtable, "groups_id_tech")) {
-                    $add_filters[] = "group_tech";
-                }
-                if ($DB->fieldExists($itemtable, "users_id_tech")) {
-                    $add_filters[] = "user_tech";
-                }
-                if ($DB->fieldExists($itemtable, "states_id")) {
-                    $add_filters[] = "state";
-                }
-                if ($itemtable == Ticket::getTable()) {
-                    $add_filters[] = "tickettype";
-                }
-
-                return $add_filters;
-            };
-
             $cards = [];
             $menu_itemtypes = $this->getMenuItemtypes();
-            $DB_read = DBConnection::getReadConnection();
 
             foreach ($menu_itemtypes as $firstlvl => $itemtypes) {
                 foreach ($itemtypes as $itemtype) {
@@ -1182,10 +1110,7 @@ HTML;
                         'itemtype'   => "\\$itemtype",
                         'label'      => sprintf(__("Number of %s"), $itemtype::getTypeName()),
                         'provider'   => "Glpi\\Dashboard\\Provider::bigNumber$itemtype",
-                        'filters'    => array_merge([
-                            'dates',
-                            'dates_mod',
-                        ], $add_filters_fct($itemtype::getTable(), $DB_read))
+                        'filters'    => Filter::getAppliableFilters($itemtype::getTable()),
                     ];
                 }
             }
@@ -1204,10 +1129,7 @@ HTML;
                     'group'      =>  _n('Device', 'Devices', 1),
                     'label'      => $label,
                     'provider'   => "Glpi\\Dashboard\\Provider::multipleNumber" . $itemtype . "By" . $fk_itemtype,
-                    'filters'    => array_merge([
-                        'dates',
-                        'dates_mod',
-                    ], $add_filters_fct($itemtype::getTable(), $DB_read))
+                    'filters'    => Filter::getAppliableFilters($itemtype::getTable()),
                 ];
 
                 $clean_itemtype = str_replace('\\', '_', $itemtype);
@@ -1217,10 +1139,7 @@ HTML;
                     'itemtype'   => "\\$itemtype",
                     'label'      => sprintf(__("Number of %s"), $itemtype::getTypeName()),
                     'provider'   => "Glpi\\Dashboard\\Provider::bigNumber$itemtype",
-                    'filters'    => array_merge([
-                        'dates',
-                        'dates_mod',
-                    ], $add_filters_fct($itemtype::getTable(), $DB_read))
+                    'filters'    => Filter::getAppliableFilters($itemtype::getTable()),
                 ];
             }
 
@@ -1232,10 +1151,7 @@ HTML;
                     'itemtype'   => "\\$itemtype",
                     'label'      => sprintf(__("Number of type of %s"), $itemtype::getTypeName()),
                     'provider'   => "Glpi\\Dashboard\\Provider::bigNumber$itemtype",
-                    'filters'    => array_merge([
-                        'dates',
-                        'dates_mod',
-                    ], $add_filters_fct($itemtype::getTable(), $DB_read))
+                    'filters'    => Filter::getAppliableFilters($itemtype::getTable()),
                 ];
             }
 
@@ -1269,10 +1185,7 @@ HTML;
                         'group'      => _n('Asset', 'Assets', Session::getPluralNumber()),
                         'label'      => $label,
                         'provider'   => "Glpi\\Dashboard\\Provider::multipleNumber" . $itemtype . "By" . $fk_itemtype,
-                        'filters'    => array_merge([
-                            'dates',
-                            'dates_mod',
-                        ], $add_filters_fct($itemtype::getTable(), $DB_read))
+                        'filters'    => Filter::getAppliableFilters($itemtype::getTable()),
                     ];
                 }
             }
@@ -1302,10 +1215,7 @@ HTML;
                         ]
                     ],
                     'cache'      => false,
-                    'filters'    => [
-                        'dates', 'dates_mod', 'itilcategory',
-                        'group_tech', 'user_tech', 'requesttype', 'location'
-                    ]
+                    'filters'    => Filter::getAppliableFilters($itemtype::getTable()),
                 ];
 
                 $cards["table_count_tickets_$case"] = [
@@ -1320,10 +1230,7 @@ HTML;
                             'validation_check_user' => true,
                         ]
                     ],
-                    'filters'    => [
-                        'dates', 'dates_mod', 'itilcategory',
-                        'group_tech', 'user_tech', 'requesttype', 'location'
-                    ]
+                    'filters'    => Filter::getAppliableFilters($itemtype::getTable()),
                 ];
             }
 
@@ -1334,10 +1241,7 @@ HTML;
                 'group'      => __('Assistance'),
                 'label'      => __("Number of tickets by month"),
                 'provider'   => "Glpi\\Dashboard\\Provider::ticketsOpened",
-                'filters'    => [
-                    'dates', 'dates_mod', 'itilcategory',
-                    'group_tech', 'user_tech', 'requesttype', 'location'
-                ]
+                'filters'    => Filter::getAppliableFilters(Ticket::getTable()),
             ];
 
             $cards["ticket_evolution"] = [
@@ -1346,10 +1250,7 @@ HTML;
                 'group'      => __('Assistance'),
                 'label'      => __("Evolution of ticket in the past year"),
                 'provider'   => "Glpi\\Dashboard\\Provider::getTicketsEvolution",
-                'filters'    => [
-                    'dates', 'dates_mod', 'itilcategory',
-                    'group_tech', 'user_tech', 'requesttype', 'location'
-                ]
+                'filters'    => Filter::getAppliableFilters(Ticket::getTable()),
             ];
 
             $cards["ticket_status"] = [
@@ -1358,10 +1259,7 @@ HTML;
                 'group'      => __('Assistance'),
                 'label'      => __("Tickets status by month"),
                 'provider'   => "Glpi\\Dashboard\\Provider::getTicketsStatus",
-                'filters'    => [
-                    'dates', 'dates_mod', 'itilcategory',
-                    'group_tech', 'user_tech', 'requesttype', 'location'
-                ]
+                'filters'    => Filter::getAppliableFilters(Ticket::getTable()),
             ];
 
             $cards["ticket_times"] = [
@@ -1370,10 +1268,7 @@ HTML;
                 'group'      => __('Assistance'),
                 'label'      => __("Tickets times (in hours)"),
                 'provider'   => "Glpi\\Dashboard\\Provider::averageTicketTimes",
-                'filters'    => [
-                    'dates', 'dates_mod', 'itilcategory',
-                    'group_tech', 'user_tech', 'requesttype', 'location'
-                ]
+                'filters'    => Filter::getAppliableFilters(Ticket::getTable()),
             ];
 
             $cards["tickets_summary"] = [
@@ -1382,10 +1277,7 @@ HTML;
                 'group'      => __('Assistance'),
                 'label'      => __("Tickets summary"),
                 'provider'   => "Glpi\\Dashboard\\Provider::getTicketSummary",
-                'filters'    => [
-                    'dates', 'dates_mod', 'itilcategory',
-                    'group_tech', 'user_tech', 'requesttype', 'location'
-                ]
+                'filters'    => Filter::getAppliableFilters(Ticket::getTable()),
             ];
 
             $case = '';
@@ -1395,10 +1287,7 @@ HTML;
                 'group'      => __('Assistance'),
                 'label'      => sprintf(__("Number of tickets by SLA status and technician")),
                 'provider'   => "Glpi\\Dashboard\\Provider::nbTicketsByAgreementStatusAndTechnician",
-                'filters'    => [
-                    'dates', 'dates_mod', 'itilcategory',
-                    'user_tech', 'requesttype', 'location'
-                ]
+                'filters'    => Filter::getAppliableFilters(Ticket::getTable()),
             ];
 
             $cards["bn_count_tickets_expired_by_tech_group"] = [
@@ -1407,10 +1296,7 @@ HTML;
                 'group'      => __('Assistance'),
                 'label'      => sprintf(__("Number of tickets by SLA status and technician group")),
                 'provider'   => "Glpi\\Dashboard\\Provider::nbTicketsByAgreementStatusAndTechnicianGroup",
-                'filters'    => [
-                    'dates', 'dates_mod', 'itilcategory',
-                    'group_tech', 'requesttype', 'location'
-                ]
+                'filters'    => Filter::getAppliableFilters(Ticket::getTable()),
             ];
 
             foreach (
@@ -1427,10 +1313,7 @@ HTML;
                     'group'      => __('Assistance'),
                     'label'      => $label,
                     'provider'   => "Glpi\\Dashboard\\Provider::multipleNumberTicketBy$itemtype",
-                    'filters'    => [
-                        'dates', 'dates_mod', 'itilcategory',
-                        'group_tech', 'user_tech', 'requesttype', 'location'
-                    ]
+                    'filters'    => Filter::getAppliableFilters($itemtype::getTable()),
                 ];
             }
 
@@ -1453,10 +1336,7 @@ HTML;
                     'args'       => [
                         'case' => $type,
                     ],
-                    'filters'    => [
-                        'dates', 'dates_mod', 'itilcategory',
-                        'group_tech', 'user_tech', 'requesttype', 'location'
-                    ]
+                    'filters'    => Filter::getAppliableFilters(Ticket::getTable()),
                 ];
             }
 
@@ -1465,7 +1345,7 @@ HTML;
                 'label'      => __("List of reminders"),
                 'group'      => __('Tools'),
                 'provider'   => "Glpi\\Dashboard\\Provider::getArticleListReminder",
-                'filters'    => ['dates', 'dates_mod']
+                'filters'    => Filter::getAppliableFilters(Reminder::getTable()),
             ];
 
             $cards["markdown_editable"] = [
