@@ -852,16 +852,20 @@ class Group extends CommonTreeDropdown
 
         if ($nb) {
             Html::printAjaxPager('', $start, $nb);
-            foreach ($datas as $data) {
-                if (!($item = getItemForItemtype($data['itemtype']))) {
-                    continue;
+            $show_massive_actions = false;
+            if (self::canUpdate()) {
+                foreach ($datas as $data) {
+                    if (!($item = getItemForItemtype($data['itemtype']))) {
+                        continue;
+                    }
+                    if ($item->canUpdate($data['items_id']) || $item->canView($data['items_id'])) {
+                        // Show massive actions if there is at least one viewable/updatable item.
+                        $show_massive_actions = true;
+                        break;
+                    }
                 }
             }
-            if (
-                $item->canUpdate($data['items_id'])
-                || ($item->canView($data['items_id'])
-                 && self::canUpdate())
-            ) {
+            if ($show_massive_actions) {
                 Html::openMassiveActionsForm('mass' . __CLASS__ . $rand);
                 echo Html::hidden('field', ['value'                 => $field,
                     'data-glpicore-ma-tags' => 'common'
@@ -883,11 +887,7 @@ class Group extends CommonTreeDropdown
             }
             echo "<table class='tab_cadre_fixehov'>";
             $header_begin  = "<tr><th width='10'>";
-            if (
-                $item->canUpdate($data['items_id'])
-                || ($item->canView($data['items_id'])
-                 && self::canUpdate())
-            ) {
+            if ($show_massive_actions) {
                 $header_top    = Html::getCheckAllAsCheckbox('mass' . __CLASS__ . $rand);
                 $header_bottom = Html::getCheckAllAsCheckbox('mass' . __CLASS__ . $rand);
             } else {
@@ -944,11 +944,7 @@ class Group extends CommonTreeDropdown
         }
 
         if ($nb) {
-            if (
-                $item->canUpdate($data['items_id'])
-                || ($item->canView($data['items_id'])
-                 && self::canUpdate())
-            ) {
+            if ($show_massive_actions) {
                 $massiveactionparams['ontop'] = false;
                 Html::showMassiveActions($massiveactionparams);
             }
