@@ -824,7 +824,7 @@ class Infocom extends CommonDBChild
                 throw new \RuntimeException('Empty date');
             }
             $fiscaldate = new \DateTime($fiscaldate, new DateTimeZone($TZ));
-        } catch (\Exception $e) {
+        } catch (\Throwable $e) {
             Session::addMessageAfterRedirect(
                 __('Please fill you fiscal year date in preferences.'),
                 false,
@@ -843,7 +843,7 @@ class Infocom extends CommonDBChild
             } else {
                 $usedate = new \DateTime($buydate, new DateTimeZone($TZ));
             }
-        } catch (\Exception $e) {
+        } catch (\Throwable $e) {
             Session::addMessageAfterRedirect(
                 __('Please fill either buy or use date in preferences.'),
                 false,
@@ -939,9 +939,9 @@ class Infocom extends CommonDBChild
      * @param number  $va            valeur d'acquisition
      * @param number  $duree         duree d'amortissement
      * @param number  $coef          coefficient d'amortissement
-     * @param string  $date_achat    Date d'achat
-     * @param string  $date_use      Date d'utilisation
-     * @param string  $date_tax      date du debut de l'annee fiscale
+     * @param string|null  $date_achat    Date d'achat
+     * @param string|null  $date_use      Date d'utilisation
+     * @param string|null  $date_tax      date du debut de l'annee fiscale
      * @param string  $view          "n" pour l'annee en cours ou "all" pour le tableau complet (default 'n')
      *
      * @return float|array
@@ -1024,7 +1024,15 @@ class Infocom extends CommonDBChild
                     $dureedegressif = $duree - $dureelineaire; // calcul de la duree de l'amortissement
                                                         // en mode degressif
                     $mrt            = $va;
-                  // amortissement degressif pour les premieres annees
+
+                    $tab = [
+                        'annee'    => [],
+                        'vcnetdeb' => [],
+                        'vcnetfin' => [],
+                        'annuite'  => [],
+                    ];
+
+                    // amortissement degressif pour les premieres annees
                     for ($i = 1; $i <= $dureedegressif; $i++) {
                         $tab['annee'][$i]    = $date_Y + $i - 1;
                         $tab['vcnetdeb'][$i] = $mrt; // Pour chaque annee on calcule la valeur comptable nette
@@ -1701,6 +1709,14 @@ class Infocom extends CommonDBChild
             'datatype'           => 'bool'
         ];
 
+        $tab[] = [
+            'id'                 => '173',
+            'table'              => 'glpi_businesscriticities',
+            'field'              => 'completename',
+            'name'               => _n('Business criticity', 'Business criticities', 1),
+            'datatype'           => 'dropdown'
+        ];
+
         return $tab;
     }
 
@@ -1745,7 +1761,7 @@ class Infocom extends CommonDBChild
             return __('Never');
         }
 
-        if (($from == null) || empty($from)) {
+        if (empty($from)) {
             return "";
         }
 
