@@ -228,7 +228,7 @@ class VirtualMachine extends InventoryAsset
                 foreach (ComputerVirtualMachine::getUUIDRestrictCriteria($handled_input['uuid'] ?? '') as $cleaned_uuid) {
                     $sinput = [
                         'name'                     => $handled_input['name'] ?? '',
-                        'uuid'                     => $cleaned_uuid ?? '',
+                        'uuid'                     => Sanitizer::unsanitize($cleaned_uuid ?? ''),
                         'virtualmachinesystems_id' => $handled_input['virtualmachinesystems_id'] ?? 0
                     ];
 
@@ -258,20 +258,9 @@ class VirtualMachine extends InventoryAsset
         }
 
         if ((!$this->main_asset || !$this->main_asset->isPartial()) && count($db_vms) != 0) {
-           // Delete virtual machines links in DB
+            // Delete virtual machines links in DB
             foreach ($db_vms as $idtmp => $data) {
-                if (isset($data['uuid']) && $data['uuid'] != '') {
-                    $vm = new \stdClass();
-                    $vm->uuid = $data['uuid'];
-                    $computers_vm_id = $this->getExistingVMAsComputer($vm);
-                    if ($computers_vm_id) {
-                        $computer->getFromDB($computers_vm_id);
-                        if ($computer->fields['is_dynamic'] == 1) {
-                            $computer->delete(['id' => $computers_vm_id], false);
-                        }
-                    }
-                }
-                $computerVirtualmachine->delete(['id' => $idtmp]);
+                $computerVirtualmachine->delete(['id' => $idtmp], 1);
             }
         }
 
@@ -350,6 +339,19 @@ class VirtualMachine extends InventoryAsset
                     $this->handlePorts('Computer', $computers_vm_id);
                 }
 
+                //manage operating system
+                if (property_exists($vm, 'operatingsystem')) {
+                    $os = new OperatingSystem($computervm, (array)$vm->operatingsystem);
+                    if ($os->checkConf($this->conf)) {
+                        $os->setAgent($this->getAgent());
+                        $os->setExtraData($this->data);
+                        $os->setEntityID($computervm->getEntityID());
+                        $os->prepare();
+                        $os->handleLinks();
+                        $os->handle();
+                    }
+                }
+
                 //manage extra components created form hosts information
                 if ($this->conf->vm_components) {
                     foreach ($this->vmcomponents as $key => $assetitem) {
