@@ -44,7 +44,7 @@ class KnowbaseItem_Comment extends CommonDBTM
 
     public function getTabNameForItem(CommonGLPI $item, $withtemplate = 0)
     {
-        if (!$item->canUpdateItem()) {
+        if (!($item instanceof KnowbaseItem) || !$item->canComment()) {
             return '';
         }
 
@@ -281,7 +281,7 @@ class KnowbaseItem_Comment extends CommonDBTM
             $html .= "<div class='h_date'>" . Html::convDateTime($comment['date_creation']) . "</div>";
             $html .= "<div class='h_user'>";
             $thumbnail_url = User::getThumbnailURLForPicture($user->fields['picture']);
-            $style = !empty($thumbnail_url) ? "background-image: url(\"$thumbnail_url\")" : ("background-color: " . $user->getUserInitialsBgColor());
+            $style = !empty($thumbnail_url) ? "background-image: url(\"$thumbnail_url\"); background-color: inherit;" : ("background-color: " . $user->getUserInitialsBgColor());
             $html .= '<a href="' . $user->getLinkURL() . '">';
             $html .= "<span class='avatar avatar-md rounded' style='{$style}'>";
             if (empty($thumbnail_url)) {
