@@ -869,19 +869,14 @@ class Migration
         $rule['comment']     = sprintf(__('Automatically generated by GLPI %s'), $this->version);
         $rule['description'] = '';
 
-       // Compute ranking
-        $sql = "SELECT MAX(`ranking`) AS `rank`
-              FROM `glpi_rules`
-              WHERE `sub_type` = '" . $rule['sub_type'] . "'";
-        $result = $DB->query($sql);
-
-        $ranking = 1;
-        if ($DB->numrows($result) > 0) {
-            $datas = $DB->fetchAssoc($result);
-            $ranking = $datas["rank"] + 1;
+        // Compute ranking
+        $ruleinst = new $rule['sub_type']();
+        $ranking = $ruleinst->getNextRanking();
+        if (!$ranking) {
+            $ranking = 1;
         }
 
-       // The rule itself
+        // The rule itself
         $values = ['ranking' => $ranking];
         foreach ($rule as $field => $value) {
             $values[$field] = $value;
@@ -889,7 +884,7 @@ class Migration
         $DB->insertOrDie('glpi_rules', $values);
         $rid = $DB->insertId();
 
-       // The rule criteria
+        // The rule criteria
         foreach ($criteria as $criterion) {
             $values = ['rules_id' => $rid];
             foreach ($criterion as $field => $value) {
@@ -898,7 +893,7 @@ class Migration
             $DB->insertOrDie('glpi_rulecriterias', $values);
         }
 
-       // The rule criteria actions
+        // The rule criteria actions
         foreach ($actions as $action) {
             $values = ['rules_id' => $rid];
             foreach ($action as $field => $value) {
