@@ -408,6 +408,14 @@ class NetworkEquipment extends CommonDBTM
             ]
         ];
 
+        $tab[] = [
+            'id'                 => '12',
+            'table'              => $this->getTable(),
+            'field'              => 'uuid',
+            'name'               => __('UUID'),
+            'datatype'           => 'string',
+        ];
+
         $tab[] = [
             'id'                 => '14',
             'table'              => $this->getTable(),
@@ -492,9 +500,9 @@ class NetworkEquipment extends CommonDBTM
 
         $tab = array_merge($tab, Rack::rawSearchOptionsToAdd(get_class($this)));
 
-        $tab = array_merge($tab, Socket::rawSearchOptionsToAdd(get_class($this)));
+        $tab = array_merge($tab, Socket::rawSearchOptionsToAdd());
 
-        $tab = array_merge($tab, SNMPCredential::rawSearchOptionsToAdd(get_class($this)));
+        $tab = array_merge($tab, SNMPCredential::rawSearchOptionsToAdd());
 
         return $tab;
     }
