@@ -166,6 +166,9 @@ class Notification extends CommonDBTM
             $menu['options']['notification']['page']            = Notification::getSearchURL(false);
             $menu['options']['notification']['links']['add']    = Notification::getFormURL(false);
             $menu['options']['notification']['links']['search'] = Notification::getSearchURL(false);
+            //saved search list
+            $menu['options']['notification']['links']['lists']  = "";
+            $menu['options']['notification']['lists_itemtype']  = Notification::getType();
 
             $menu['options']['notificationtemplate']['title']
                         = _n('Notification template', 'Notification templates', Session::getPluralNumber());
@@ -175,6 +178,9 @@ class Notification extends CommonDBTM
                         = NotificationTemplate::getFormURL(false);
             $menu['options']['notificationtemplate']['links']['search']
                         = NotificationTemplate::getSearchURL(false);
+            //saved search list
+            $menu['options']['notificationtemplate']['links']['lists']  = "";
+            $menu['options']['notificationtemplate']['lists_itemtype']  = NotificationTemplate::getType();
         }
         if (count($menu)) {
             return $menu;
