@@ -71,7 +71,7 @@ class RSSFeed extends CommonDBVisible implements ExtraVisibilityCriteria
 
     public static $rightname    = 'rssfeed_public';
 
-
+    const PERSONAL = 128;
 
     public static function getTypeName($nb = 0)
     {
@@ -86,16 +86,14 @@ class RSSFeed extends CommonDBVisible implements ExtraVisibilityCriteria
     public static function canCreate()
     {
 
-        return (Session::haveRight(self::$rightname, CREATE)
-              || Session::getCurrentInterface() != 'helpdesk');
+        return (Session::haveRightsOr(self::$rightname, [CREATE, self::PERSONAL]));
     }
 
 
     public static function canView()
     {
 
-        return (Session::haveRight('rssfeed_public', READ)
-              || Session::getCurrentInterface() != 'helpdesk');
+        return (Session::haveRightsOr(self::$rightname, [READ, self::PERSONAL]));
     }
 
 
@@ -131,7 +129,7 @@ class RSSFeed extends CommonDBVisible implements ExtraVisibilityCriteria
      **/
     public static function canUpdate()
     {
-        return (Session::getCurrentInterface() != 'helpdesk');
+        return (Session::haveRightsOr(self::$rightname, [UPDATE, self::PERSONAL]));
     }
 
 
@@ -141,7 +139,7 @@ class RSSFeed extends CommonDBVisible implements ExtraVisibilityCriteria
      **/
     public static function canPurge()
     {
-        return (Session::getCurrentInterface() != 'helpdesk');
+        return (Session::haveRightsOr(self::$rightname, [PURGE, self::PERSONAL]));
     }
 
 
@@ -792,14 +790,7 @@ class RSSFeed extends CommonDBVisible implements ExtraVisibilityCriteria
             echo Dropdown::getYesNo($this->fields['have_error']);
         }
         echo "</td>";
-        if ($this->fields['have_error']) {
-            echo "<td>" . __('RSS feeds found');
-            echo "</td><td>";
-            $this->showDiscoveredFeeds();
-            echo "</td>\n";
-        } else {
-            echo "<td colspan='2'>&nbsp;</td>";
-        }
+        echo "<td colspan='2'>&nbsp;</td>";
         echo "</tr>";
 
         $this->showFormButtons($options);
@@ -876,9 +867,12 @@ class RSSFeed extends CommonDBVisible implements ExtraVisibilityCriteria
      * Show discovered feeds
      *
      * @return void
+     *
+     * @deprecated
      **/
     public function showDiscoveredFeeds()
     {
+        Toolbox::deprecated();
         if (!Toolbox::isUrlSafe($this->fields['url'])) {
             return;
         }
@@ -1118,6 +1112,7 @@ class RSSFeed extends CommonDBVisible implements ExtraVisibilityCriteria
             $values = [READ => __('Read')];
         } else {
             $values = parent::getRights();
+            $values[self::PERSONAL] = __('Manage personal');
         }
         return $values;
     }
