@@ -35,15 +35,6 @@
 
 class RuleDictionnaryPeripheralModel extends RuleDictionnaryDropdown
 {
-    /**
-     * Constructor
-     **/
-    public function __construct()
-    {
-        parent::__construct('RuleDictionnaryPeripheralModel');
-    }
-
-
     /**
      * @see Rule::getCriterias()
      **/
